/*
 jGuard is a security framework based on top of jaas (java authentication and authorization security).
 it is written for web applications, to resolve simply, access control problems.
 version $Name$
 http://sourceforge.net/projects/jguard/

 Copyright (C) 2004  Charles GAY

 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
 License as published by the Free Software Foundation; either
 version 2.1 of the License, or (at your option) any later version.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Lesser General Public License for more details.

 You should have received a copy of the GNU Lesser General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


 jGuard project home page:
 http://sourceforge.net/projects/jguard/

 */
package net.sf.jguard.example.swing;

import java.awt.Dialog;
import java.awt.Frame;
import java.awt.GridLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.IOException;

import javax.security.auth.callback.Callback;
import javax.security.auth.callback.CallbackHandler;
import javax.security.auth.callback.NameCallback;
import javax.security.auth.callback.PasswordCallback;
import javax.security.auth.callback.UnsupportedCallbackException;
import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JLabel;
import javax.swing.JPasswordField;
import javax.swing.JTextField;

/**
 * 
 * @author <a href="mailto:vberetti@users.sourceforge.net">Vincent Beretti</a>
 */
public class SwingCallbackHandler implements CallbackHandler{

	private JDialog dialog;
	private JTextField nameField;
	private JPasswordField passwordField;

	private static final int NB_ROWS = 3;

	public SwingCallbackHandler(Frame parent) {
		dialog = new JDialog(parent, true);
		dialog.getContentPane().setLayout(new GridLayout(NB_ROWS,2));
		dialog.setLocation(parent.getLocation());
	}

	public void handle(Callback[] callbacks) throws IOException, UnsupportedCallbackException {
		for(int i=0; i < callbacks.length && i < NB_ROWS ; i++){
			if(callbacks[i] instanceof NameCallback){
				NameCallback nameCallback = (NameCallback) callbacks[i];
				dialog.getContentPane().add(new JLabel(nameCallback.getPrompt()));
				nameField = new JTextField();
				dialog.getContentPane().add(nameField);
			}else if(callbacks[i] instanceof PasswordCallback){
				PasswordCallback passwordCallback = (PasswordCallback) callbacks[i];
				dialog.getContentPane().add(new JLabel(passwordCallback.getPrompt()));
				passwordField = new JPasswordField();
				dialog.getContentPane().add(passwordField);
			}
		}
		JButton ok = new JButton("ok");
		ConfirmListener listener = new ConfirmListener(dialog);
		ok.addActionListener(listener);
		dialog.getContentPane().add(ok);
		dialog.setSize(200, 100);
		dialog.pack();
		dialog.setVisible(true);

		for(int i=0; i < callbacks.length && i < NB_ROWS ; i++){
			if(callbacks[i] instanceof NameCallback){
				NameCallback nameCallback = (NameCallback) callbacks[i];
				nameCallback.setName(nameField.getText());
			}else if(callbacks[i] instanceof PasswordCallback){
				PasswordCallback passwordCallback = (PasswordCallback) callbacks[i];
				passwordCallback.setPassword(passwordField.getPassword());
			}
		}
	}

}

class ConfirmListener implements ActionListener{

	private Dialog dialog;

	public ConfirmListener(Dialog dialog){
		this.dialog = dialog;
	}

	public void actionPerformed(ActionEvent e) {
		dialog.dispose();
	}

}
